using System;
using System.Collections;

namespace CommonUI.Common.Collections
{
	/// <summary>
	/// Summary description for ObjectSequence.
	/// </summary>
	/// 
	[Serializable]
	abstract public class ObjectSequence : IEnumerable
	{
		protected ArrayList sequence = new ArrayList();

		protected void AddElement(object element) {
			//DBC.CheckPre("element must not be null", element != null);
			//DBC.CheckPre("element must not exist in sequence", Contains(element) == false);
			
			sequence.Add(element);
		}

		public bool Contains(object element) {
			//DBC.CheckPre("element must not be null", element != null);

			return sequence.Contains(element);
		}

		public int Count {
			get { return sequence.Count; }
		}

		protected object this[int index] {
			get {
				//DBC.CheckPre("index must NOT be negative", index >= 0);
				//DBC.CheckPre("index must be less than or equal to count", index <= Count);
				return sequence[index];
			}
		}

		/// <summary>
		/// Sort the collection using the underlying implementations sort method.
		/// Note this collection is not automatically sorted so new insertions are not
		/// gauranteed to maintain sort order.
		/// </summary>
		public void Sort() {
			sequence.Sort();
		}

		public void Clear() {
			sequence.Clear();
		}

		public void Remove(object element) {
			//DBC.CheckPre("element must not be null", element != null);
			//DBC.CheckPre("element must exist in the sequence", Contains(element));
			sequence.Remove(element);
		}

		//		public void Insert(int index, object element)
		//		{
		//			DBC.CheckPre("element must not be null", element != null);
		//			DBC.CheckPre("index must NOT be negative", index >= 0);
		//			DBC.CheckPre("index must be less than or equal to count", index <= Count);
		//			sequence.Insert(index, element);
		//		}

		public void AddRange(ICollection newElements) {
			//DBC.CheckPre("newElements must not be null", newElements != null);
			sequence.AddRange(newElements);
		}

		public IEnumerator GetEnumerator() {
			return sequence.GetEnumerator();
		}

		public int IndexOf(object element) {
			//DBC.CheckPre("element must not be null", element != null);

			return sequence.IndexOf(element);
		}
	}
}
