using System;
using System.Data;

namespace CommonUI
{
	/// <summary>
	/// Summary description for GridColumn.
	/// </summary>
	public class GridColumn: ICloneable
	{
		public const int DEFAULT_WIDTH = 10;

		public GridColumn(string caption, string mappingName, int width, bool isReadOnly, bool resizeToFit, bool showEllipsis) {
			//DBC.CheckPre("caption cannot be null", caption != null);
			//DBC.CheckPre("caption cannot be 0 length", caption.Length > 0);
			//DBC.CheckPre("mappingName cannot be null", mappingName != null);
			//DBC.CheckPre("mappingName cannot be 0 length", mappingName.Length > 0);

			this.caption = caption;
			this.mappingName = mappingName;
			this.width = width;
			this.isReadOnly = isReadOnly;
			this.resizeToFit = resizeToFit;
			this.showEllipsis = showEllipsis;
		}

		public GridColumn(string caption, string mappingName, int width, bool isReadOnly, bool resizeToFit, bool showEllipsis, bool useComboBox, object dataSource, string displayMember) {
			//DBC.CheckPre("caption cannot be null", caption != null);
			//DBC.CheckPre("caption cannot be 0 length", caption.Length > 0);
			//DBC.CheckPre("mappingName cannot be null", mappingName != null);
			//DBC.CheckPre("mappingName cannot be 0 length", mappingName.Length > 0);

			this.caption = caption;
			this.mappingName = mappingName;
			this.width = width;
			this.isReadOnly = isReadOnly;
			this.resizeToFit = resizeToFit;
			this.showEllipsis = showEllipsis;
			this.useComboBox = useComboBox;
			this.displayMember = displayMember;
			this.dataSource = dataSource;
		}

		/// <summary>
		/// Create a gridColumn with default width, and not readonly, and resizeTofit = true
		/// Typoically used with position cols
		/// </summary>
		public GridColumn(string caption, string mappingName) : this(caption, mappingName, DEFAULT_WIDTH, false, true, false) {
		 }

		/// <summary>
		/// Create a gridColumn with default width, readonly = true, resizeTofit = true, specified format stirng
		/// Typoically used with position cols
		/// </summary>
		public GridColumn(string caption, string mappingName, string formatString) : this(caption, mappingName, DEFAULT_WIDTH, true, true, false) {
			//DBC.CheckPre("formatString cannot be null", formatString != null);
			this.formatString = formatString;
		}

		/// <summary>
		/// Create a gridColumn with default width and resizeTofit = true
		/// </summary>
		public GridColumn(string caption, string mappingName, bool isReadOnly) : this(caption, mappingName, DEFAULT_WIDTH, isReadOnly, true, false) {
		 }

		private string caption;
		/// <summary>
		/// The caption to display for this item
		/// </summary>
		public string Caption {
			get { return caption; }
		}

		private string mappingName;	// This the underlying tables' column name 
		/// <summary>
		/// The name of the column from the datasource
		/// </summary>
		public string MappingName {
			get { return mappingName; }
		}

		private bool isReadOnly;
		public bool IsReadOnly {
			get { return isReadOnly; }
		}

		private int width; 
		public int Width {
			get { return width; }
			set { width = value; }
		}

		private bool resizeToFit;	// Also handles any covered ranges
		public bool ResizeToFit {
			get { return resizeToFit; }
			set { resizeToFit = value;}
		}

		private bool showEllipsis;
		public bool ShowEllipsis {
			get { return showEllipsis; }
		}
		
		protected string formatString;// Made protected because SummaryColumn sets it
		/// <summary>
		/// Used to define format of numeric strings
		/// </summary>
		public string FormatString {
			get { return formatString;}
			set { formatString = value; }
		}

		private bool useComboBox=false;
		public bool UseComboBox{
			get{
				return useComboBox;
			}
		}

		private string displayMember;
		public string DisplayMember{
			get{
				return displayMember;
			}
		}

		private object dataSource;
		public object DataSource{
			get{
				return dataSource;
			}
		}

		#region ICloneable Members

		public object Clone() {
			GridColumn cloned = new GridColumn(this.caption, this.mappingName, this.width, this.isReadOnly, this.resizeToFit, this.showEllipsis);
			cloned.formatString = this.formatString;

			return cloned;
		}

		#endregion
	}
}
