using System;
using CommonUI.Common.Collections; 

namespace CommonUI
{
	/// <summary>
	/// Summary description for GridColumnCollection.
	/// </summary>
	public class GridColumnCollection : ObjectSequence
	{
		/// <summary>
		/// Redefines the baseclass implementation to give a more concrete type for indexor
		/// Don't forget thast new is required because the method signature is the same
		/// as the one found in Objectsequecne, ie name(args) - return type is not incldued!!
		/// </summary>
		public new GridColumn this[int index] {
			get { return (GridColumn)base[index]; }
		}

		/// <summary>
		/// The baseclass has an AddElement method which we call from here
		/// By adding this Add method we tie callers into only being able to
		/// add BoundColumn objects
		/// </summary>
		public void Add(GridColumn gridColumn) {
			//DBC.CheckPre("gridColumn must not be null", gridColumn != null);
			//DBC.CheckPre("gridColumn mapping name '" + gridColumn.MappingName + "' must be unqiue", 
				//this.ContainsMappingName(gridColumn.MappingName) == false);

			base.AddElement(gridColumn);
		}

		public void AddRange(GridColumn[] gridColumns) {
			//DBC.CheckPre("GridColumns cannot be null", gridColumns != null);
			base.AddRange(gridColumns);
		}

		public bool ContainsMappingName(string mappingName) {
			//DBC.CheckPre("mappingName must not be null", mappingName != null);

			bool itemFound = false;

			GridColumn gridColumn = this.GetByMappingName(mappingName);
			if (gridColumn != null) {
				itemFound = true;
			}
			
			return itemFound;
		}

		public int IndexOf(string mappingName) {
			int index = 0;
			bool foundItem = false;

			foreach(GridColumn existingColumn in base.sequence) {
				if (existingColumn.MappingName == mappingName) {
					foundItem = true;
					break;
				}

				index ++;
			}

			if (! foundItem) {
				index = -1; // Not found
			}

			return index;
		}

		public GridColumn GetByMappingName(string mappingName) {
			//DBC.CheckPre("mappingName must not be null", mappingName != null);

			GridColumn foundItem = null;

			foreach(GridColumn existingColumn in base.sequence) {
				if (existingColumn.MappingName == mappingName) {
					foundItem = existingColumn;
					break;
				}
			}
			return foundItem;
		}

		public GridColumn GetByCaption(string caption) {
			//DBC.CheckPre("caption must not be null", caption != null);

			GridColumn foundItem = null;

			foreach(GridColumn existingColumn in base.sequence) {
				if (existingColumn.Caption == caption) {
					foundItem = existingColumn;
					break;
				}
			}
			return foundItem;
		}
	}
}
