using System;

using Syncfusion.Windows.Forms.Grid.Grouping;

namespace CommonUI
{
	/// <summary>
	/// Summary description for MergedColumnBuilder.
	/// </summary>
	public class MergedColumnBuilder
	{
		private readonly MergedColumnHeaderCollection mergedColumns;
		private readonly GroupingGrid groupingGrid;

		public MergedColumnBuilder(MergedColumnHeaderCollection mergedColumns, GroupingGrid groupingGrid) {
			//DBC.CheckPre("mergedColumns cannot be null", mergedColumns != null);
			//DBC.CheckPre("groupingGrid cannot be null", groupingGrid != null);

			this.mergedColumns = mergedColumns;
			this.groupingGrid = groupingGrid;
		}

		public void Apply() {

			GridGroupingControl syncGrid = groupingGrid.SyncfusionGridControl;

			// Take if off, if it's there already which it might be if being called 2nd time
			syncGrid.TableModel.QueryCoveredRange -= 
				new Syncfusion.Windows.Forms.Grid.GridQueryCoveredRangeEventHandler(groupingGrid.TableModel_QueryCoveredRange);

			if (this.mergedColumns.Count > 0) {

				// The grid actually needs these boys at painting time
				groupingGrid.MergedColumnHeaders = mergedColumns;

				// for each definition we need to set the col caption for the first item
				GridColumnDescriptorCollection columns = syncGrid.TableDescriptor.Columns;			
				for(int i = 0; i < this.mergedColumns.Count; i ++) {
					MergedColumnHeader mergedCol = this.mergedColumns[i];
					columns[mergedCol.GridColumn1.MappingName].HeaderText = mergedCol.Caption;
				}

				// If there are some we need to hook into the querycovered range event
				syncGrid.TableModel.QueryCoveredRange += 
					new Syncfusion.Windows.Forms.Grid.GridQueryCoveredRangeEventHandler(groupingGrid.TableModel_QueryCoveredRange);

			}

		}
	}
}
