using System;
using System.Collections;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Windows.Forms;
using Syncfusion.Grouping;
using Syncfusion.Windows.Forms;
using Syncfusion.Windows.Forms.Grid;
using Syncfusion.Windows.Forms.Grid.Grouping;

using CommonUI;

namespace ProjectControls
{
	/// <summary>
	/// Summary description for ViewGridControl.
	/// </summary>
	public class ViewGridControl : System.Windows.Forms.UserControl
	{
		private CommonUI.GroupingGrid groupingGridControl;
		private const int HEADER_COL_HEIGHT = 30;		
		private System.Windows.Forms.ImageList imageList1;
		private System.ComponentModel.IContainer components;
		public delegate void DelegateMethodNoArgs();
		public event DelegateMethodNoArgs RefreshView;
		private bool ignoreReset = false;

		public ViewGridControl()
		{
			// This call is required by the Windows.Forms Form Designer.
			InitializeComponent();
			this.groupingGridControl.SyncfusionGridControl.QueryCellStyleInfo += new GridTableCellStyleInfoEventHandler(SyncfusionGridControl_QueryCellStyleInfo);
			this.groupingGridControl.SyncfusionGridControl.SourceListListChanged +=new TableListChangedEventHandler(SyncfusionGridControl_ListChangedEventHandler);
			groupingGridControl.ColumnHeaderHeight = HEADER_COL_HEIGHT;					
			groupingGridControl.GridTableModel.Options.EnterKeyBehavior = GridDirectionType.None;
			this.Height = 640;
			this.Width = 1000;

		}

		/// <summary> 
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if(components != null)
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		#region Component Designer generated code
		/// <summary> 
		/// Required method for Designer support - do not modify 
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
			this.components = new System.ComponentModel.Container();
			System.Resources.ResourceManager resources = new System.Resources.ResourceManager(typeof(ViewGridControl));
			this.groupingGridControl = new CommonUI.GroupingGrid();
			this.imageList1 = new System.Windows.Forms.ImageList(this.components);
			this.SuspendLayout();
			// 
			// groupingGridControl
			// 
			this.groupingGridControl.AllowDragColumns = false;
			this.groupingGridControl.AllowDragSelectedCols = false;
			this.groupingGridControl.AllowEdit = true;
			this.groupingGridControl.AllowNew = false;
			this.groupingGridControl.AllowRemove = false;
			this.groupingGridControl.AutoHighlightRow = false;
			this.groupingGridControl.BorderStyle = System.Windows.Forms.BorderStyle.Fixed3D;
			this.groupingGridControl.CausesValidation = false;
			this.groupingGridControl.CellActivationBehaviour = Syncfusion.Windows.Forms.Grid.GridCellActivateAction.SelectAll;
			this.groupingGridControl.ClearCellsOnDeleteKey = true;
			this.groupingGridControl.ColumnHeaderHeight = 22;
			this.groupingGridControl.CommandStackEnabled = false;
			this.groupingGridControl.CurrentField = null;
			this.groupingGridControl.CurrentRecord = null;
			this.groupingGridControl.DataSource = null;
			this.groupingGridControl.FrozenColumns = 0;
			this.groupingGridControl.GridBackColor = System.Drawing.SystemColors.Control;
			this.groupingGridControl.GridLeftColIndex = 1;
			this.groupingGridControl.GridTopRowIndex = 1;
			this.groupingGridControl.HScrollPixelPos = 0;
			this.groupingGridControl.IgnoreCurrentCellActivatedEvent = false;
			this.groupingGridControl.IgnoreTopRowChanging = false;
			this.groupingGridControl.Location = new System.Drawing.Point(8, 8);
			this.groupingGridControl.MergedColumnHeaders = null;
			this.groupingGridControl.Name = "groupingGridControl";
			this.groupingGridControl.SelectionMode = System.Windows.Forms.SelectionMode.None;
			this.groupingGridControl.ShowFullGroupingText = false;
			this.groupingGridControl.ShowGroupDropArea = false;
			this.groupingGridControl.ShowNavigationBar = false;
			this.groupingGridControl.ShowRowHeader = true;
			this.groupingGridControl.Size = new System.Drawing.Size(280, 176);
			this.groupingGridControl.TabIndex = 0;
			this.groupingGridControl.ToolTipDisplayColumn = null;
			this.groupingGridControl.ToolTipValues = null;
			this.groupingGridControl.UseAlphaBlendHighLighting = false;
			this.groupingGridControl.VScrollPixelPos = 0;
			// 
			// imageList1
			// 
			this.imageList1.ImageSize = new System.Drawing.Size(16, 16);
			this.imageList1.ImageStream = ((System.Windows.Forms.ImageListStreamer)(resources.GetObject("imageList1.ImageStream")));
			this.imageList1.TransparentColor = System.Drawing.Color.Transparent;
			// 
			// ViewGridControl
			// 
			this.Controls.Add(this.groupingGridControl);
			this.Name = "ViewGridControl";
			this.Size = new System.Drawing.Size(352, 280);
			this.Resize += new System.EventHandler(this.ViewGridControl_Resize);
			this.ResumeLayout(false);

		}
		#endregion

		public void ExpandAll() {
			groupingGridControl.ExpandAll();
		}
	
		public void CollapseAll() {
			groupingGridControl.CollapseAll();
		}

		#region Public Properties
		public bool ShowFullGroupingText {
			get { return groupingGridControl.ShowFullGroupingText; }
			set { groupingGridControl.ShowFullGroupingText = value; }
		}

		public System.Windows.Forms.BorderStyle BorderStyle {
			get { return this.groupingGridControl.BorderStyle; }
			set { this.groupingGridControl.BorderStyle = value; }
		}

		public GroupingGrid GroupingGrid {
			get { return groupingGridControl; }
		}
		#endregion

		public GridVisibleColumnDescriptorCollection VisibleColumns {
			get { return groupingGridControl.SyncfusionGridControl.TableDescriptor.VisibleColumns; }
		}

		public SortColumnDescriptorCollection GroupedColumns {
			get { return groupingGridControl.SyncfusionGridControl.TableDescriptor.GroupedColumns; }
		}	

		private void ViewGridControl_Resize(object sender, System.EventArgs e) {			
			this.groupingGridControl.Left = 0;
			this.groupingGridControl.Top = 0;
			this.groupingGridControl.Width = this.Width;
			this.groupingGridControl.Height = this.Height;			
		}

		private void SyncfusionGridControl_QueryCellStyleInfo(object sender, GridTableCellStyleInfoEventArgs e) {
			
			if(e.TableCellIdentity.TableCellType == GridTableCellType.AlternateRecordFieldCell 
				|| e.TableCellIdentity.TableCellType == GridTableCellType.RecordFieldCell) {
				if(e.TableCellIdentity.Column != null) {
					   
					if(e.TableCellIdentity.Column.Name == "Img") {
						GridRecord rec = e.TableCellIdentity.DisplayElement.ParentRecord as GridRecord;
						if(rec != null) {
							object assetId = rec.GetValue("Id");
													
							double outAssetId;
							if(double.TryParse(assetId.ToString(), System.Globalization.NumberStyles.Any, null, out outAssetId)) {
								if(outAssetId > 0) {								
									e.Style.CellValue = imageList1.Images[0];								
								}
								else if(outAssetId < 0) {								
									e.Style.CellValue =  imageList1.Images[1];								
								}
								else {								
									//e.Style.CellValue = imageList1.Images[2];								
								}
							}       
						}
					}
				
					if(e.TableCellIdentity.Column.Name == "EditedImage") {
					
						GridRecord rec = e.TableCellIdentity.DisplayElement.ParentRecord as GridRecord;
						if(rec != null) {
							object TimeStamp = rec.GetValue("Date");
							if(TimeStamp != System.DBNull.Value) {
								
								DateTime dt;
								dt = DateTime.Parse(TimeStamp.ToString());
								if(dt.Date == DateTime.Now.Date.AddDays(2)){								
									e.Style.CellValue = imageList1.Images[2];								
								}						
							}
						}
					}
				}

			}
			
		}

		private void SyncfusionGridControl_ListChangedEventHandler(object sender, TableListChangedEventArgs e) {
			try {
				
				if(e.ListChangedType == ListChangedType.ItemChanged){					
					if(this.ignoreReset) {
						e.ShouldIgnoreReset = true;
						e.ShouldResetCurrentRecord = false;
					}
					if(e.Table.CurrentRecord != null) {
						//object SelCheckBoxValue = e.Table.CurrentRecord.GetValue("Selected");											
						RefreshviewDetails();						
					}						
				
				}

			} catch (Exception ex) {
				Console.WriteLine("Error while updating the asset view" + ex);
			}
		}
	
		public void RefreshviewDetails() {
			if (RefreshView!=null) {
				RefreshView();
			}
		}

		public bool IgnoreReset {
			get {
				return this.ignoreReset;
			}
			set {
				this.ignoreReset = value;
			}
		}
	}
}
